@@ -1,22 +1,24 @@
 from django.test import RequestFactory, TestCase
 
 import wagtail
-from wagtail.core.models import Site
 
 from flags.conditions import RequiredForCondition
 
 from wagtailflags.conditions import site_condition
 
 
+if wagtail.VERSION > (3, 0, 0):  # pragma: no cover
+    from wagtail.models import Site
+else:  # pragma: no cover
+    from wagtail.core.models import Site
+
+
 class SiteConditionTestCase(TestCase):
     def setUp(self):
         self.site = Site.objects.get(is_default_site=True)
         self.factory = RequestFactory()
         self.request = self.factory.get("/")
-        if wagtail.VERSION >= (2, 9):  # pragma: no cover
-            Site.find_for_request(self.request)
-        else:  # pragma: no cover
-            self.request.site = self.site
+        Site.find_for_request(self.request)
 
     def test_site_valid_string(self):
         self.assertTrue(site_condition("localhost:80", request=self.request))
