@@ -2,13 +2,19 @@ from unittest import mock
 
 from django.test import TestCase
 
-from wagtail.tests.utils import WagtailTestUtils
+import wagtail
 
 from flags.models import FlagState
 
 from wagtailflags.signals import flag_disabled, flag_enabled
 
 
+if wagtail.VERSION >= (3, 0, 0):  # pragma: no cover
+    from wagtail.test.utils import WagtailTestUtils
+else:  # pragma: no cover
+    from wagtail.tests.utils import WagtailTestUtils
+
+
 class SignalsTestCase(TestCase, WagtailTestUtils):
     def setUp(self):
         self.login()
