@@ -1,10 +1,16 @@
 from django.test import TestCase
 
-from wagtail.tests.utils import WagtailTestUtils
+import wagtail
 
 from flags.models import FlagState
 
 
+if wagtail.VERSION >= (3, 0, 0):  # pragma: no cover
+    from wagtail.test.utils import WagtailTestUtils
+else:  # pragma: no cover
+    from wagtail.tests.utils import WagtailTestUtils
+
+
 class TestWagtailFlagsViews(TestCase, WagtailTestUtils):
     def setUp(self):
         self.login()
