@@ -2,17 +2,18 @@ import django
 from django.templatetags.static import static
 from django.utils.html import format_html
 
+import wagtail
 from wagtail.admin.menu import MenuItem
-from wagtail.core import hooks
 
 from wagtailflags import views
 
 
-try:  # pragma: no cover; >= 2.0
-    from django.urls import include, re_path, reverse
-except ImportError:  # pragma: no cover; fallback for Django < 2.0
-    from django.conf.urls import include, url as re_path
-    from django.core.urlresolvers import reverse
+if wagtail.VERSION >= (3, 0, 0):  # pragma: no cover
+    from wagtail import hooks
+else:  # pragma: no cover
+    from wagtail.core import hooks
+
+from django.urls import include, re_path, reverse
 
 
 @hooks.register("register_settings_menu_item")
@@ -20,7 +21,7 @@ def register_flags_menu():
     return MenuItem(
         "Flags",
         reverse("wagtailflags:list"),
-        classnames="icon icon-tag",
+        icon_name="tag",
         order=10000,
     )
 
